from a10sdk.common.A10BaseClass import A10BaseClass


class PriorityList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param priority: {"description": "Set priority for Designated Router election (Priority value)", "format": "number", "default": 64, "maximum": 127, "minimum": 0, "type": "number"}
    :param level: {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify priority for level-1 routing; 'level-2': Specify priority for level-2 routing; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "priority-list"
        self.DeviceProxy = ""
        self.priority = ""
        self.level = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class HelloIntervalMinimalList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param hello_interval_minimal: {"default": 0, "type": "number", "description": "Set Hello holdtime 1 second, interval depends on multiplier", "format": "flag"}
    :param level: {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify hello-interval for level-1 IIHs; 'level-2': Specify hello-interval for level-2 IIHs; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "hello-interval-minimal-list"
        self.DeviceProxy = ""
        self.hello_interval_minimal = ""
        self.level = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class MeshGroup(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param value: {"description": "Mesh group number", "format": "number", "maximum": 4294967295, "minimum": 1, "not": "blocked", "type": "number"}
    :param blocked: {"default": 0, "not": "value", "type": "number", "description": "Block LSPs on this interface", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "mesh-group"
        self.DeviceProxy = ""
        self.value = ""
        self.blocked = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class BfdCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param disable: {"default": 0, "type": "number", "description": "Disable BFD", "format": "flag"}
    :param bfd: {"default": 0, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "bfd-cfg"
        self.DeviceProxy = ""
        self.disable = ""
        self.bfd = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class CsnpIntervalList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param level: {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Speficy interval for level-1 CSNPs; 'level-2': Specify interval for level-2 CSNPs; ", "format": "enum"}
    :param csnp_interval: {"description": "Set CSNP interval in seconds (CSNP interval value)", "format": "number", "default": 10, "maximum": 65535, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "csnp-interval-list"
        self.DeviceProxy = ""
        self.level = ""
        self.csnp_interval = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class PasswordList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param password: {"minLength": 1, "maxLength": 254, "type": "string", "description": "Configure the authentication password for interface", "format": "string-rlx"}
    :param level: {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify password for level-1 PDUs; 'level-2': Specify password for level-2 PDUs; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "password-list"
        self.DeviceProxy = ""
        self.password = ""
        self.level = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class KeyChainList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param key_chain: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Authentication key-chain (Name of key-chain)", "format": "string"}
    :param level: {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication key-chain for level-1 PDUs; 'level-2': Specify authentication key-chain for level-2 PDUs; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "key-chain-list"
        self.DeviceProxy = ""
        self.key_chain = ""
        self.level = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ModeList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param mode: {"enum": ["md5"], "type": "string", "description": "'md5': Keyed message digest; ", "format": "enum"}
    :param level: {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication mode for level-1 PDUs; 'level-2': Specify authentication mode for level-2 PDUs; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "mode-list"
        self.DeviceProxy = ""
        self.mode = ""
        self.level = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class SendOnlyList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param send_only: {"default": 0, "type": "number", "description": "Authentication send-only", "format": "flag"}
    :param level: {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication send-only for level-1 PDUs; 'level-2': Specify authentication send-only for level-2 PDUs; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "send-only-list"
        self.DeviceProxy = ""
        self.send_only = ""
        self.level = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Authentication(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param key_chain_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"key-chain": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Authentication key-chain (Name of key-chain)", "format": "string"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication key-chain for level-1 PDUs; 'level-2': Specify authentication key-chain for level-2 PDUs; ", "format": "enum"}}}]}
    :param mode_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "mode": {"enum": ["md5"], "type": "string", "description": "'md5': Keyed message digest; ", "format": "enum"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication mode for level-1 PDUs; 'level-2': Specify authentication mode for level-2 PDUs; ", "format": "enum"}}}]}
    :param send_only_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"send-only": {"default": 0, "type": "number", "description": "Authentication send-only", "format": "flag"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication send-only for level-1 PDUs; 'level-2': Specify authentication send-only for level-2 PDUs; ", "format": "enum"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "authentication"
        self.DeviceProxy = ""
        self.key_chain_list = []
        self.mode_list = []
        self.send_only_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class WideMetricList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param wide_metric: {"description": "Configure the wide metric for interface", "format": "number", "default": 10, "maximum": 16777214, "minimum": 1, "type": "number"}
    :param level: {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Apply metric to level-1 links; 'level-2': Apply metric to level-2 links; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "wide-metric-list"
        self.DeviceProxy = ""
        self.wide_metric = ""
        self.level = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class HelloIntervalList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param hello_interval: {"description": "Set Hello interval in seconds (Hello interval value)", "format": "number", "default": 10, "maximum": 65535, "minimum": 1, "type": "number"}
    :param level: {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify hello-interval for level-1 IIHs; 'level-2': Specify hello-interval for level-2 IIHs; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "hello-interval-list"
        self.DeviceProxy = ""
        self.hello_interval = ""
        self.level = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class HelloMultiplierList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param hello_multiplier: {"description": "Set multiplier for Hello holding time (Hello multiplier value)", "format": "number", "default": 3, "maximum": 100, "minimum": 2, "type": "number"}
    :param level: {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify hello multiplier for level-1 IIHs; 'level-2': Specify hello multiplier for level-2 IIHs; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "hello-multiplier-list"
        self.DeviceProxy = ""
        self.hello_multiplier = ""
        self.level = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class MetricList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param metric: {"description": "Configure the metric for interface (Default metric)", "format": "number", "default": 10, "maximum": 63, "minimum": 1, "type": "number"}
    :param level: {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Apply metric to level-1 links; 'level-2': Apply metric to level-2 links; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "metric-list"
        self.DeviceProxy = ""
        self.metric = ""
        self.level = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Isis(A10BaseClass):
    
    """Class Description::
    ISIS.

    Class isis supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param priority_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"priority": {"description": "Set priority for Designated Router election (Priority value)", "format": "number", "default": 64, "maximum": 127, "minimum": 0, "type": "number"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify priority for level-1 routing; 'level-2': Specify priority for level-2 routing; ", "format": "enum"}}}]}
    :param hello_interval_minimal_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"hello-interval-minimal": {"default": 0, "type": "number", "description": "Set Hello holdtime 1 second, interval depends on multiplier", "format": "flag"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify hello-interval for level-1 IIHs; 'level-2': Specify hello-interval for level-2 IIHs; ", "format": "enum"}}}]}
    :param network: {"optional": true, "enum": ["broadcast", "point-to-point"], "type": "string", "description": "'broadcast': Specify IS-IS broadcast multi-access network; 'point-to-point': Specify IS-IS point-to-point network; ", "format": "enum"}
    :param csnp_interval_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Speficy interval for level-1 CSNPs; 'level-2': Specify interval for level-2 CSNPs; ", "format": "enum"}, "optional": true, "csnp-interval": {"description": "Set CSNP interval in seconds (CSNP interval value)", "format": "number", "default": 10, "maximum": 65535, "minimum": 1, "type": "number"}}}]}
    :param retransmit_interval: {"description": "Set per-LSP retransmission interval (Interval between retransmissions of the same LSP (seconds))", "format": "number", "default": 5, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}
    :param password_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"password": {"minLength": 1, "maxLength": 254, "type": "string", "description": "Configure the authentication password for interface", "format": "string-rlx"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify password for level-1 PDUs; 'level-2': Specify password for level-2 PDUs; ", "format": "enum"}}}]}
    :param wide_metric_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "wide-metric": {"description": "Configure the wide metric for interface", "format": "number", "default": 10, "maximum": 16777214, "minimum": 1, "type": "number"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Apply metric to level-1 links; 'level-2': Apply metric to level-2 links; ", "format": "enum"}}}]}
    :param hello_interval_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "hello-interval": {"description": "Set Hello interval in seconds (Hello interval value)", "format": "number", "default": 10, "maximum": 65535, "minimum": 1, "type": "number"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify hello-interval for level-1 IIHs; 'level-2': Specify hello-interval for level-2 IIHs; ", "format": "enum"}}}]}
    :param lsp_interval: {"description": "Set LSP transmission interval (LSP transmission interval (milliseconds))", "format": "number", "default": 33, "optional": true, "maximum": 4294967295, "minimum": 1, "type": "number"}
    :param circuit_type: {"description": "'level-1': Level-1 only adjacencies are formed; 'level-1-2': Level-1-2 adjacencies are formed; 'level-2-only': Level-2 only adjacencies are formed; ", "format": "enum", "default": "level-1-2", "type": "string", "enum": ["level-1", "level-1-2", "level-2-only"], "optional": true}
    :param hello_multiplier_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "hello-multiplier": {"description": "Set multiplier for Hello holding time (Hello multiplier value)", "format": "number", "default": 3, "maximum": 100, "minimum": 2, "type": "number"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify hello multiplier for level-1 IIHs; 'level-2': Specify hello multiplier for level-2 IIHs; ", "format": "enum"}}}]}
    :param metric_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"metric": {"description": "Configure the metric for interface (Default metric)", "format": "number", "default": 10, "maximum": 63, "minimum": 1, "type": "number"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Apply metric to level-1 links; 'level-2': Apply metric to level-2 links; ", "format": "enum"}}}]}
    :param hello: {"optional": true, "enum": ["padding"], "type": "string", "description": "'padding': Pad hello packets; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/interface/lif/{ifnum}/isis`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "isis"
        self.a10_url="/axapi/v3/interface/lif/{ifnum}/isis"
        self.DeviceProxy = ""
        self.priority_list = []
        self.hello_interval_minimal_list = []
        self.mesh_group = {}
        self.network = ""
        self.bfd_cfg = {}
        self.csnp_interval_list = []
        self.retransmit_interval = ""
        self.password_list = []
        self.authentication = {}
        self.wide_metric_list = []
        self.hello_interval_list = []
        self.lsp_interval = ""
        self.circuit_type = ""
        self.hello_multiplier_list = []
        self.metric_list = []
        self.hello = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Techreport(A10BaseClass):
    
    """Class Description::
    Configure show tech.

    Class techreport supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param disable: {"default": 0, "optional": true, "type": "number", "description": "Disable the polling techreport", "format": "flag"}
    :param priority_partition_list: {"minItems": 1, "items": {"type": "priority-partition"}, "uniqueItems": true, "array": [{"required": ["part-name"], "properties": {"part-name": {"description": "Name of partition always want to show in showtech (shared is always shown by default)", "format": "string", "minLength": 1, "optional": false, "maxLength": 14, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/techreport/priority-partition/{part-name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/techreport`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "techreport"
        self.a10_url="/axapi/v3/techreport"
        self.DeviceProxy = ""
        self.disable = ""
        self.priority_partition_list = []
        self.interval = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class GslbIpListAddrList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ip: {"type": "string", "description": "Specify IP address", "format": "ipv4-address"}
    :param ip_mask: {"type": "string", "description": "IP mask", "format": "ipv4-netmask"}
    :param id: {"description": "ID Number", "minimum": 0, "type": "number", "maximum": 31, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "gslb-ip-list-addr-list"
        self.DeviceProxy = ""
        self.ip = ""
        self.ip_mask = ""
        self.A10WW_id = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class IpListList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param gslb_ip_list_addr_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ip": {"type": "string", "description": "Specify IP address", "format": "ipv4-address"}, "ip-mask": {"type": "string", "description": "IP mask", "format": "ipv4-netmask"}, "optional": true, "id": {"description": "ID Number", "minimum": 0, "type": "number", "maximum": 31, "format": "number"}}}]}
    :param gslb_ip_list_filename: {"description": "Load IP List file (IP List filename)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param gslb_ip_list_obj_name: {"description": "Specify IP List name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ip-list-list"
        self.DeviceProxy = ""
        self.gslb_ip_list_addr_list = []
        self.gslb_ip_list_filename = ""
        self.gslb_ip_list_obj_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Gslb(A10BaseClass):
    
    """Class Description::
    Global server load balance commands.

    Class gslb supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param service_group_list: {"minItems": 1, "items": {"type": "service-group"}, "uniqueItems": true, "array": [{"required": ["service-group-name"], "properties": {"member": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"member-name": {"platform-specific-default": 1, "type": "string", "description": "Service name", "format": "string"}, "optional": true}}]}, "service-group-name": {"description": "Specify Service Group name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "disable-site-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "disable-site": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Site name", "format": "string"}}}]}, "disable": {"default": 0, "optional": true, "type": "number", "description": "Disable all members", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/gslb/service-group/{service-group-name}"}
    :param geo_location_list: {"minItems": 1, "items": {"type": "geo-location"}, "uniqueItems": true, "array": [{"required": ["geo-locn-obj-name"], "properties": {"geo-locn-obj-name": {"description": "Specify geo-location name, section range is (1-15)", "format": "string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}, "geo-locn-multiple-addresses": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"first-ip-address": {"type": "string", "description": "Specify IP information (Specify IP address)", "format": "ipv4-address"}, "first-ipv6-address": {"type": "string", "description": "Specify IPv6 address", "format": "ipv6-address"}, "geol-ipv4-mask": {"not": "ip-addr2", "type": "string", "description": "Specify IPv4 mask", "format": "ipv4-netmask"}, "ip-addr2": {"not": "geol-ipv4-mask", "type": "string", "description": "Specify IP address range", "format": "ipv4-address"}, "ipv6-addr2": {"not": "geol-ipv6-mask", "type": "string", "description": "Specify IPv6 address range", "format": "ipv6-address"}, "geol-ipv6-mask": {"description": "Specify IPv6 mask", "format": "number", "maximum": 128, "minimum": 0, "not": "ipv6-addr2", "type": "number"}, "optional": true}}]}}}], "type": "array", "$ref": "/axapi/v3/gslb/geo-location/{geo-locn-obj-name}"}
    :param policy_list: {"minItems": 1, "items": {"type": "policy"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"weighted-ip-enable": {"default": 0, "optional": true, "type": "number", "description": "Enable Select Service-IP by weighted preference", "format": "flag"}, "alias-admin-preference": {"default": 0, "optional": true, "type": "number", "description": "Select alias name having maximum admin preference", "format": "flag"}, "least-response": {"default": 0, "optional": true, "type": "number", "description": "Least response selection", "format": "flag"}, "auto-map": {"type": "object", "properties": {"all": {"default": 0, "not": "module-type", "type": "number", "description": "All modules", "format": "flag"}, "module-disable": {"default": 0, "type": "number", "description": "Specify Disable Auto Map Module", "format": "flag"}, "module-type": {"not": "all", "enum": ["slb-virtual-server", "slb-device", "slb-server", "gslb-service-ip", "gslb-site", "gslb-group", "hostname"], "type": "string", "format": "enum-list"}, "ttl": {"description": "Specify Auto Map TTL (TTL, default is 300)", "format": "number", "default": 300, "maximum": 65535, "minimum": 1, "type": "number"}}}, "bw-cost-fail-break": {"default": 0, "optional": true, "type": "number", "description": "Break when exceed limit", "format": "flag"}, "metric-fail-break": {"default": 0, "optional": true, "type": "number", "description": "Break if no valid Service-IP", "format": "flag"}, "weighted-ip": {"default": 0, "optional": true, "type": "number", "description": "Select Service-IP by weighted preference", "format": "flag"}, "active-rdt": {"type": "object", "properties": {"ignore-id": {"description": "Ignore IP Address specified in IP List by ID", "minimum": 0, "type": "number", "maximum": 31, "format": "number"}, "keep-tracking": {"default": 0, "type": "number", "description": "Keep tracking client even round-delay-time samples are ready", "format": "flag"}, "enable": {"default": 0, "type": "number", "description": "Enable the active rdt", "format": "flag"}, "samples": {"description": "Specify samples number for round-delay-time (Number of samples,default is 5)", "format": "number", "default": 5, "maximum": 8, "minimum": 1, "type": "number"}, "skip": {"description": "Skip query if round-delay-time samples are not ready (Specify maximum skip count,default is 3)", "format": "number", "default": 3, "maximum": 31, "minimum": 1, "type": "number"}, "fail-break": {"default": 0, "type": "number", "description": "Break when no valid RDT", "format": "flag"}, "limit": {"description": "Limit of allowed RDT, default is 16383 (Limit, unit: millisecond)", "format": "number", "default": 16383, "maximum": 16383, "minimum": 1, "type": "number"}, "timeout": {"description": "Specify timeout if round-delay-time samples are not ready (Specify timeout, unit:sec,default is 3)", "format": "number", "default": 3, "maximum": 255, "minimum": 1, "type": "number"}, "single-shot": {"default": 0, "type": "number", "description": "Single Shot RDT", "format": "flag"}, "difference": {"description": "The difference between the round-delay-time, default is 0", "format": "number", "default": 0, "maximum": 16383, "minimum": 0, "type": "number"}, "tolerance": {"description": "The difference percentage between the round-delay-time, default is 10 (Tolerance)", "format": "number", "default": 10, "maximum": 100, "minimum": 0, "type": "number"}}}, "round-robin": {"default": 1, "optional": true, "type": "number", "description": "Round robin selection, enabled by default", "format": "flag"}, "capacity": {"type": "object", "properties": {"threshold": {"description": "Specify capacity threshold, default is 90", "format": "number", "default": 90, "maximum": 100, "minimum": 0, "type": "number"}, "capacity-enable": {"default": 0, "type": "number", "description": "Enable capacity", "format": "flag"}, "capacity-fail-break": {"default": 0, "type": "number", "description": "Break when exceed threshold", "format": "flag"}}}, "metric-type": {"optional": true, "enum": ["health-check", "weighted-ip", "weighted-site", "capacity", "active-servers", "active-rdt", "geographic", "connection-load", "num-session", "admin-preference", "bw-cost", "least-response", "admin-ip"], "type": "string", "format": "enum-list"}, "num-session-tolerance": {"description": "The difference between the available sessions, default is 10 (Tolerance)", "format": "number", "default": 10, "optional": true, "maximum": 100, "minimum": 0, "type": "number"}, "geo-location-match": {"type": "object", "properties": {"geo-type-overlap": {"enum": ["global", "policy"], "type": "string", "description": "'global': Global Geo-location; 'policy': Policy Geo-location; ", "format": "enum"}, "overlap": {"default": 0, "type": "number", "description": "Enable overlap mode to do longest match", "format": "flag"}, "match-first": {"default": "global", "enum": ["global", "policy"], "type": "string", "description": "'global': Global Geo-location; 'policy': Policy Geo-location; ", "format": "enum"}}}, "metric-order": {"default": 0, "optional": true, "type": "number", "description": "Specify order of metric", "format": "flag"}, "top-only": {"default": 0, "optional": true, "type": "number", "description": "Return highest priority server only", "format": "flag"}, "dns": {"type": "object", "properties": {"external-soa": {"default": 0, "type": "number", "description": "Return DNS response with external SOA Record", "format": "flag"}, "server-sec": {"default": 0, "type": "number", "description": "Provide DNSSEC support", "format": "flag"}, "sticky-ipv6-mask": {"description": "Specify IPv6 mask length, default is 128", "format": "number", "default": 128, "maximum": 128, "minimum": 1, "type": "number"}, "sticky": {"default": 0, "type": "number", "description": "Make DNS Record sticky for certain time", "format": "flag"}, "delegation": {"default": 0, "type": "number", "description": "Zone Delegation", "format": "flag"}, "active-only-fail-safe": {"default": 0, "type": "number", "description": "Continue if no candidate", "format": "flag"}, "cname-detect": {"default": 1, "type": "number", "description": "Apply GSLB for DNS Server response when service is Canonical Name (CNAME)", "format": "flag"}, "ttl": {"description": "Specify the TTL value contained in DNS record (TTL value, unit: second, default is 10)", "format": "number", "default": 10, "maximum": 1000000000, "minimum": 0, "not": "use-server-ttl", "type": "number"}, "server-full-list": {"default": 0, "type": "number", "description": "Append All A Records in Authoritative Section", "format": "flag"}, "server-ptr": {"default": 0, "type": "number", "description": "Provide PTR Records", "format": "flag"}, "selected-only": {"default": 0, "type": "number", "description": "Only keep selected servers", "format": "flag"}, "dns-addition-mx": {"default": 0, "type": "number", "description": "Append MX Records in Addition Section", "format": "flag"}, "block-type": {"enum": ["a", "aaaa", "ns", "mx", "srv", "cname", "ptr", "soa", "txt"], "type": "string", "format": "enum-list"}, "backup-alias": {"default": 0, "type": "number", "description": "Return alias name when fail", "format": "flag"}, "server-any": {"default": 0, "type": "number", "description": "Provide All Records", "format": "flag"}, "hint": {"default": "addition", "enum": ["none", "answer", "addition"], "type": "string", "description": "'none': None; 'answer': Append Hint Records in DNS Answer Section; 'addition': Append Hint Records in DNS Addition Section; ", "format": "enum"}, "cache": {"default": 0, "type": "number", "description": "Cache DNS Server response", "format": "flag"}, "external-ip": {"default": 1, "type": "number", "description": "Return DNS response with external IP address", "format": "flag"}, "server-txt": {"default": 0, "type": "number", "description": "Provide TXT Records", "format": "flag"}, "server-addition-mx": {"default": 0, "type": "number", "description": "Append MX Records in Addition Section", "format": "flag"}, "aging-time": {"description": "Specify aging-time, default is TTL in DNS record, unit: second (Aging time, default 0 means using TTL in DNS record as aging time)", "format": "number", "default": 0, "maximum": 1000000000, "minimum": 0, "type": "number"}, "block-action": {"default": 0, "type": "number", "description": "Specify Action", "format": "flag"}, "ipv6": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"dns-ipv6-mapping-type": {"enum": ["addition", "answer", "exclusive", "replace"], "type": "string", "description": "'addition': Append Mapped Record in DNS Addition Section; 'answer': Append Mapped Record in DNS Answer Section; 'exclusive': Only return AAAA Record; 'replace': Replace Record with Mapped Record; ", "format": "enum"}, "optional": true, "dns-ipv6-option": {"enum": ["mix", "smart", "mapping"], "type": "string", "description": "'mix': Return both AAAA Record and A Record; 'smart': Return AAAA Record by DNS Query Type; 'mapping': Map A Record to AAAA Record; ", "format": "enum"}}}]}, "selected-only-value": {"description": "Answer Number", "minimum": 1, "type": "number", "maximum": 128, "format": "number"}, "geoloc-action": {"default": 0, "type": "number", "description": "Apply DNS action by geo-location", "format": "flag"}, "server-ns": {"default": 0, "type": "number", "description": "Provide NS Records", "format": "flag"}, "action-type": {"enum": ["drop", "reject", "ignore"], "type": "string", "description": "'drop': Drop query; 'reject': Send refuse response; 'ignore': Send empty response; ", "format": "enum"}, "active-only": {"default": 0, "type": "number", "description": "Only keep active servers", "format": "flag"}, "block-value": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "block-value": {"description": "Specify Type Number", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}}}]}, "server-srv": {"default": 0, "type": "number", "description": "Provide SRV Records", "format": "flag"}, "server-auto-ptr": {"default": 0, "type": "number", "description": "Provide PTR Records automatically", "format": "flag"}, "server-authoritative": {"default": 0, "type": "number", "description": "As authoritative server", "format": "flag"}, "use-server-ttl": {"default": 0, "not": "ttl", "type": "number", "description": "Use DNS Server Response TTL value in GSLB Proxy mode", "format": "flag"}, "proxy-block-port-range-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"proxy-block-range-from": {"type": "number", "description": "Specify Type Range (From)", "format": "number"}, "optional": true, "proxy-block-range-to": {"type": "number", "description": "To", "format": "number"}}}]}, "ip-replace": {"default": 0, "type": "number", "description": "Replace DNS Server Response with GSLB Service-IPs", "format": "flag"}, "sticky-mask": {"type": "string", "description": "Specify IP mask, default is /32 default /32", "format": "ipv4-netmask-brief"}, "geoloc-alias": {"default": 0, "type": "number", "description": "Return alias name by geo-location", "format": "flag"}, "logging": {"enum": ["none", "query", "response", "both"], "type": "string", "description": "'none': None; 'query': DNS Query; 'response': DNS Response; 'both': Both DNS Query and Response; ", "format": "enum"}, "backup-server": {"default": 0, "type": "number", "description": "Return fallback server when fail", "format": "flag"}, "sticky-aging-time": {"description": "Specify aging-time, unit: min, default is 5 (Aging time)", "format": "number", "default": 5, "maximum": 65535, "minimum": 1, "type": "number"}, "geoloc-policy": {"default": 0, "type": "number", "description": "Apply different policy by geo-location", "format": "flag"}, "server": {"default": 0, "type": "number", "description": "Run GSLB as DNS server mode", "format": "flag"}, "server-ns-list": {"default": 0, "type": "number", "description": "Append All NS Records in Authoritative Section", "format": "flag"}, "server-auto-ns": {"default": 0, "type": "number", "description": "Provide PTR Records automatically", "format": "flag"}, "action": {"default": 0, "type": "number", "description": "Apply DNS action for service", "format": "flag"}, "dns-auto-map": {"default": 0, "type": "number", "description": "Automatically build DNS Infrastructure", "format": "flag"}, "server-mx": {"default": 0, "type": "number", "description": "Provide MX Records", "format": "flag"}}}, "weighted-ip-total-hits": {"default": 0, "optional": true, "type": "number", "description": "Weighted by total hits", "format": "flag"}, "weighted-site-total-hits": {"default": 0, "optional": true, "type": "number", "description": "Weighted by total hits", "format": "flag"}, "weighted-site-enable": {"default": 0, "optional": true, "type": "number", "description": "Enable Select Service-IP by weighted site preference", "format": "flag"}, "bw-cost": {"default": 0, "optional": true, "type": "number", "description": "Select site with minimum bandwidth cost", "format": "flag"}, "metric-force-check": {"default": 0, "optional": true, "type": "number", "description": "Always check Service-IP for all enabled metrics", "format": "flag"}, "admin-ip-enable": {"default": 0, "optional": true, "type": "number", "description": "Enable admin ip", "format": "flag"}, "geo-location-list": {"minItems": 1, "items": {"type": "geo-location"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"ip-multiple-fields": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ip-addr2-sub": {"type": "string", "description": "Specify IP address range", "format": "ipv4-address"}, "optional": true, "ip-sub": {"type": "string", "description": "Specify IP information", "format": "ipv4-address"}, "ip-mask-sub": {"type": "string", "description": "Specify IP/mask format (Specify IP address mask)", "format": "ipv4-netmask-brief"}}}]}, "name": {"description": "Specify geo-location name, section range is (1-15)", "format": "string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}, "ipv6-multiple-fields": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ipv6-mask-sub": {"description": "Specify IPv6/mask format (Specify IP address mask)", "minimum": 0, "type": "number", "maximum": 128, "format": "number"}, "ipv6-sub": {"type": "string", "description": "Specify IPv6 information", "format": "ipv6-address"}, "optional": true, "ipv6-addr2-sub": {"type": "string", "description": "Specify IPv6 address range", "format": "ipv6-address"}}}]}}}], "type": "array", "$ref": "/axapi/v3/gslb/policy/{name}/geo-location/{name}"}, "weighted-alias": {"default": 0, "optional": true, "type": "number", "description": "Select alias name by weighted preference", "format": "flag"}, "bw-cost-enable": {"default": 0, "optional": true, "type": "number", "description": "Enable bw cost", "format": "flag"}, "num-session-enable": {"default": 0, "optional": true, "type": "number", "description": "Enable Select Service-IP for device having maximum number of available sessions", "format": "flag"}, "name": {"description": "Specify policy name", "format": "string", "default": "default", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "active-servers-enable": {"default": 0, "optional": true, "type": "number", "description": "Enable Select Service-IP with the highest number of active servers", "format": "flag"}, "admin-ip": {"default": 0, "optional": true, "type": "number", "description": "Select Service-IP based on admin list", "format": "flag"}, "active-servers-fail-break": {"default": 0, "optional": true, "type": "number", "description": "Break when no active server", "format": "flag"}, "connection-load": {"type": "object", "properties": {"connection-load-enable": {"default": 0, "type": "number", "description": "Enable connection-load", "format": "flag"}, "connection-load-interval": {"description": "Interval between two samples, Unit: second (Interval value,default is 5)", "format": "number", "default": 5, "maximum": 60, "minimum": 1, "type": "number"}, "limit": {"default": 0, "type": "number", "description": "Limit of maxinum connection load, default is unlimited", "format": "flag"}, "connection-load-samples": {"description": "Specify samples for connection-load (Number of samples used to calculate the connection load, default is 5)", "format": "number", "default": 5, "maximum": 8, "minimum": 1, "type": "number"}, "connection-load-limit": {"description": "The value of the connection-load limit, default is unlimited", "minimum": 1, "type": "number", "maximum": 999999999, "format": "number"}, "connection-load-fail-break": {"default": 0, "type": "number", "description": "Break when exceed limit", "format": "flag"}}}, "ip-list": {"description": "Specify IP List (IP List Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/gslb/ip-list"}, "admin-preference": {"default": 0, "optional": true, "type": "number", "description": "Select Service-IP for the device having maximum admin preference", "format": "flag"}, "weighted-site": {"default": 0, "optional": true, "type": "number", "description": "Select Service-IP by weighted site preference", "format": "flag"}, "geographic": {"default": 1, "optional": true, "type": "number", "description": "Select Service-IP by geographic", "format": "flag"}, "health-check": {"default": 1, "optional": true, "type": "number", "description": "Select Service-IP by health status", "format": "flag"}, "active-servers": {"default": 0, "optional": true, "type": "number", "description": "Select Service-IP with the highest number of active servers", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/gslb/policy/{name}"}
    :param site_list: {"minItems": 1, "items": {"type": "site"}, "uniqueItems": true, "array": [{"required": ["site-name"], "properties": {"ip-server-list": {"minItems": 1, "items": {"type": "ip-server"}, "uniqueItems": true, "array": [{"required": ["ip-server-name"], "properties": {"ip-server-name": {"description": "Specify the real server name", "format": "string", "minLength": 1, "$ref-list": ["/axapi/v3/gslb/service-ip", "/axapi/v3/slb/server"], "optional": false, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/gslb/site/{site-name}/ip-server/{ip-server-name}"}, "weight": {"description": "Specify a weight for the GSLB site (Weight, default is 1)", "format": "number", "default": 1, "optional": true, "maximum": 100, "minimum": 1, "type": "number"}, "site-name": {"description": "Specify GSLB site name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "slb-dev-list": {"minItems": 1, "items": {"type": "slb-dev"}, "uniqueItems": true, "array": [{"required": ["device-name"], "properties": {"client-ip": {"optional": true, "type": "string", "description": "Specify client IP address", "format": "ipv4-address"}, "vip-server": {"type": "object", "properties": {"vip-server-v4-list": {"minItems": 1, "items": {"type": "vip-server-v4"}, "uniqueItems": true, "array": [{"required": ["ipv4"], "properties": {"ipv4": {"optional": false, "type": "string", "description": "Specify IP address", "format": "ipv4-address"}}}], "type": "array", "$ref": "/axapi/v3/gslb/site/{site-name}/slb-dev/{device-name}/vip-server/vip-server-v4/{ipv4}"}, "vip-server-v6-list": {"minItems": 1, "items": {"type": "vip-server-v6"}, "uniqueItems": true, "array": [{"required": ["ipv6"], "properties": {"ipv6": {"optional": false, "type": "string", "description": "Specify IP address (IPv6 address)", "format": "ipv6-address"}}}], "type": "array", "$ref": "/axapi/v3/gslb/site/{site-name}/slb-dev/{device-name}/vip-server/vip-server-v6/{ipv6}"}, "vip-server-name-list": {"minItems": 1, "items": {"type": "vip-server-name"}, "uniqueItems": true, "array": [{"required": ["vip-name"], "properties": {"vip-name": {"description": "Specify a VIP name for the SLB device", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/gslb/service-ip"}}}], "type": "array", "$ref": "/axapi/v3/gslb/site/{site-name}/slb-dev/{device-name}/vip-server/vip-server-name/{vip-name}"}}}, "device-name": {"description": "Specify SLB device name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "proto-aging-fast": {"default": 1, "optional": true, "type": "number", "description": "Fast GSLB Protocol aging", "format": "flag"}, "proto-compatible": {"default": 0, "optional": true, "type": "number", "description": "Run GSLB Protocol in compatible mode", "format": "flag"}, "auto-map": {"default": 1, "optional": true, "type": "number", "description": "Enable DNS Auto Mapping", "format": "flag"}, "proto-aging-time": {"description": "Specify GSLB Protocol aging time, default is 60", "format": "number", "default": 60, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "rdt-value": {"description": "Specify Round-delay-time", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "admin-preference": {"description": "Specify administrative preference (Specify admin-preference value,default is 100)", "format": "number", "default": 100, "optional": true, "maximum": 255, "minimum": 0, "type": "number"}, "ip-address": {"optional": true, "type": "string", "description": "IP address", "format": "ipv4-address"}, "auto-detect": {"description": "'ip': Service IP only; 'port': Service Port only; 'ip-and-port': Both service IP and service port; 'disabled': disable auto-detect; ", "format": "enum", "default": "ip-and-port", "type": "string", "enum": ["ip", "port", "ip-and-port", "disabled"], "optional": true}, "health-check-action": {"description": "'health-check': Enable health Check; 'health-check-disable': Disable health check; ", "format": "enum", "default": "health-check", "type": "string", "enum": ["health-check", "health-check-disable"], "optional": true}, "max-client": {"description": "Specify maximum number of clients, default is 32768", "format": "number", "default": 32768, "optional": true, "maximum": 2147483647, "minimum": 1, "type": "number"}, "gateway-ip-addr": {"optional": true, "type": "string", "description": "IP address", "format": "ipv4-address"}}}], "type": "array", "$ref": "/axapi/v3/gslb/site/{site-name}/slb-dev/{device-name}"}, "bw-cost": {"default": 0, "optional": true, "type": "number", "description": "Specify cost of band-width", "format": "flag"}, "auto-map": {"default": 1, "optional": true, "type": "number", "description": "Enable DNS Auto Mapping", "format": "flag"}, "disable": {"default": 0, "optional": true, "type": "number", "description": "Disable all servers in the GSLB site", "format": "flag"}, "limit": {"description": "Specify the limit for bandwidth, default is unlimited", "format": "number", "type": "number", "maximum": 2147483647, "minimum": 0, "optional": true}, "template": {"description": "Specify template to collect site information (Specify template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "threshold": {"description": "Specify the threshold for limit", "format": "number", "default": 0, "optional": true, "maximum": 100, "minimum": 0, "type": "number"}, "multiple-geo-locations": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"geo-location": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Specify the geographic location of the GSLB site (Specify geo-location for this site)", "format": "string"}, "optional": true}}]}, "easy-rdt": {"type": "object", "properties": {"range-factor": {"description": "Factor of RDT Range, default is 25 (Range Factor of Smooth RDT)", "format": "number", "default": 25, "maximum": 1000, "minimum": 0, "type": "number"}, "smooth-factor": {"description": "Factor of Smooth RDT, default is 10", "format": "number", "default": 10, "maximum": 100, "minimum": 0, "type": "number"}, "mask": {"default": "/32", "type": "string", "description": "Client IP subnet mask, default is 32", "format": "ipv4-netmask-brief"}, "overlap": {"default": 0, "type": "number", "description": "Enable overlap for geo-location to do longest match", "format": "flag"}, "limit": {"description": "Limit of valid RDT, default is 16383 (Limit, unit: millisecond)", "format": "number", "default": 16383, "maximum": 16383, "minimum": 1, "type": "number"}, "ignore-count": {"description": "Ignore count if RDT is out of range, default is 5", "format": "number", "default": 5, "maximum": 15, "minimum": 0, "type": "number"}, "aging-time": {"description": "Aging Time, Unit: min, default is 10", "format": "number", "default": 10, "maximum": 15360, "minimum": 1, "type": "number"}, "bind-geoloc": {"default": 0, "type": "number", "description": "Bind RDT to geo-location", "format": "flag"}}}, "active-rdt": {"type": "object", "properties": {"range-factor": {"description": "Factor of RDT Range, default is 25 (Range Factor of Smooth RDT)", "format": "number", "default": 25, "maximum": 1000, "minimum": 0, "type": "number"}, "smooth-factor": {"description": "Factor of Smooth RDT, default is 10", "format": "number", "default": 10, "maximum": 100, "minimum": 0, "type": "number"}, "mask": {"default": "/32", "type": "string", "description": "Client IP subnet mask, default is 32", "format": "ipv4-netmask-brief"}, "overlap": {"default": 0, "type": "number", "description": "Enable overlap for geo-location to do longest match", "format": "flag"}, "limit": {"description": "Limit of valid RDT, default is 16383 (Limit, unit: millisecond)", "format": "number", "default": 16383, "maximum": 16383, "minimum": 1, "type": "number"}, "ignore-count": {"description": "Ignore count if RDT is out of range, default is 5", "format": "number", "default": 5, "maximum": 15, "minimum": 0, "type": "number"}, "aging-time": {"description": "Aging Time, Unit: min, default is 10", "format": "number", "default": 10, "maximum": 15360, "minimum": 1, "type": "number"}, "bind-geoloc": {"default": 0, "type": "number", "description": "Bind RDT to geo-location", "format": "flag"}}}}}], "type": "array", "$ref": "/axapi/v3/gslb/site/{site-name}"}
    :param ip_list_list: {"minItems": 1, "items": {"type": "ip-list"}, "uniqueItems": true, "array": [{"required": ["gslb-ip-list-obj-name"], "properties": {"gslb-ip-list-addr-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ip": {"type": "string", "description": "Specify IP address", "format": "ipv4-address"}, "ip-mask": {"type": "string", "description": "IP mask", "format": "ipv4-netmask"}, "optional": true, "id": {"description": "ID Number", "minimum": 0, "type": "number", "maximum": 31, "format": "number"}}}]}, "gslb-ip-list-filename": {"description": "Load IP List file (IP List filename)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "gslb-ip-list-obj-name": {"description": "Specify IP List name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/gslb/ip-list/{gslb-ip-list-obj-name}"}
    :param group_list: {"minItems": 1, "items": {"type": "group"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"enable": {"default": 0, "optional": true, "type": "number", "description": "Join GSLB Group", "format": "flag"}, "name": {"description": "Specify Group domain name", "format": "string", "default": "default", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "standalone": {"default": 0, "optional": true, "type": "number", "description": "Run GSLB Group in standalone mode", "format": "flag"}, "learn": {"default": 1, "optional": true, "type": "number", "description": "Learn neighbour information from other controllers", "format": "flag"}, "mgmt-interface": {"default": 1, "optional": true, "type": "number", "description": "Management Interface IP Address", "format": "flag"}, "dns-discover": {"default": 1, "optional": true, "type": "number", "description": "Discover member via DNS Protocol", "format": "flag"}, "priority": {"description": "Specify Local Priority, default is 100", "format": "number", "default": 100, "optional": true, "maximum": 255, "minimum": 1, "type": "number"}, "config-anywhere": {"default": 0, "optional": true, "type": "number", "description": "Every member can do config", "format": "flag"}, "data-interface": {"default": 1, "optional": true, "type": "number", "description": "Data Interface IP Address", "format": "flag"}, "auto-map-primary": {"default": 1, "optional": true, "type": "number", "description": "Primary Controller's IP address", "format": "flag"}, "auto-map-learn": {"default": 1, "optional": true, "type": "number", "description": "IP Address learned from other controller", "format": "flag"}, "primary-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "primary": {"type": "string", "description": "Specify Primary controller's IP address", "format": "ipv4-address"}}}]}, "suffix": {"description": "Set DNS Suffix (Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "config-merge": {"default": 0, "optional": true, "type": "number", "description": "Merge old master's config when new one take over", "format": "flag"}, "auto-map-smart": {"default": 1, "optional": true, "type": "number", "description": "Choose Best IP address", "format": "flag"}, "config-save": {"default": 1, "optional": true, "type": "number", "description": "Accept config-save message from master", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/gslb/group/{name}"}
    :param zone_list: {"minItems": 1, "items": {"type": "zone"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"name": {"description": "Specify the name for the DNS zone", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}, "dns-ns-record-list": {"minItems": 1, "items": {"type": "dns-ns-record"}, "uniqueItems": true, "array": [{"required": ["ns-name"], "properties": {"ns-name": {"description": "Specify Domain Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}, "ttl": {"optional": true, "type": "number", "description": "Specify TTL", "format": "number"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/dns-ns-record/{ns-name}"}, "dns-mx-record-list": {"minItems": 1, "items": {"type": "dns-mx-record"}, "uniqueItems": true, "array": [{"required": ["mx-name"], "properties": {"priority": {"description": "Specify Priority", "format": "number", "type": "number", "maximum": 65535, "minimum": 0, "optional": true}, "mx-name": {"description": "Specify Domain Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}, "ttl": {"optional": true, "type": "number", "description": "Specify TTL", "format": "number"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/dns-mx-record/{mx-name}"}, "disable": {"default": 0, "optional": true, "type": "number", "description": "Disable all services in the GSLB zone", "format": "flag"}, "template": {"type": "object", "properties": {"dnssec": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify DNSSEC template (Specify template name)", "format": "string"}}}, "ttl": {"description": "Specify the zone ttl value (TTL value, unit: second, default is 10)", "format": "number", "default": 10, "optional": true, "maximum": 1000000000, "minimum": 0, "not": "use-server-ttl", "type": "number"}, "policy": {"description": "Specify the policy for this zone (Specify policy name)", "format": "string", "default": "default", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "use-server-ttl": {"description": "Use DNS Server Response TTL value in GSLB Proxy mode", "format": "flag", "default": 0, "optional": true, "not": "ttl", "type": "number"}, "dns-soa-record": {"type": "object", "properties": {"retry": {"default": 900, "type": "number", "description": "Specify Retry Time Interval, default is 900", "format": "number"}, "soa-name": {"minLength": 1, "maxLength": 127, "type": "string", "description": "DNS Server Name", "format": "string"}, "ex-retry": {"default": 900, "type": "number", "description": "Specify Retry Time Interval, default is 900", "format": "number"}, "ex-soa-ttl": {"type": "number", "description": "Specify Negative caching TTL, default is Zone TTL", "format": "number"}, "ex-serial": {"type": "number", "description": "Specify Serial Number, default is Current Time (Time Interval)", "format": "number"}, "refresh": {"default": 3600, "type": "number", "description": "Specify Refresh Time Interval, default is 3600", "format": "number"}, "ex-mail": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Mailbox", "format": "string"}, "expire": {"default": 1209600, "type": "number", "description": "Specify Expire Time Interval, default is 1209600", "format": "number"}, "ex-expire": {"default": 1209600, "type": "number", "description": "Specify Expire Time Interval, default is 1209600", "format": "number"}, "external": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Specify External SOA Record (DNS Server Name)", "format": "string"}, "mail": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Mailbox", "format": "string"}, "serial": {"type": "number", "description": "Specify Serial Number, default is Current Time (Time Interval)", "format": "number"}, "ex-refresh": {"default": 3600, "type": "number", "description": "Specify Refresh Time Interval, default is 3600", "format": "number"}, "soa-ttl": {"type": "number", "description": "Specify Negative caching TTL, default is Zone TTL", "format": "number"}}}, "service-list": {"minItems": 1, "items": {"type": "service"}, "uniqueItems": true, "array": [{"required": ["service-port", "service-name"], "properties": {"dns-a-record": {"type": "object", "properties": {"dns-a-record-ipv6-list": {"minItems": 1, "items": {"type": "dns-a-record-ipv6"}, "uniqueItems": true, "array": [{"required": ["dns-a-record-ipv6"], "properties": {"as-replace": {"default": 0, "optional": true, "type": "number", "description": "Return this Service-IP when enable ip-replace", "format": "flag"}, "dns-a-record-ipv6": {"optional": false, "type": "string", "description": "IPV6 address", "format": "ipv6-address"}, "as-backup": {"default": 0, "optional": true, "type": "number", "description": "As backup when fail", "format": "flag"}, "weight": {"description": "Specify weight for Service-IP (Weight value)", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}, "disable": {"default": 0, "optional": true, "type": "number", "description": "Disable this Service-IP", "format": "flag"}, "static": {"default": 0, "optional": true, "type": "number", "description": "Return this Service-IP in DNS server mode", "format": "flag"}, "ttl": {"optional": true, "type": "number", "description": "Specify TTL for Service-IP", "format": "number"}, "admin-ip": {"description": "Specify admin priority of Service-IP (Specify the priority)", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}, "no-resp": {"default": 0, "optional": true, "type": "number", "description": "Don't use this Service-IP as DNS response", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-a-record/dns-a-record-ipv6/{dns-a-record-ipv6}"}, "dns-a-record-ipv4-list": {"minItems": 1, "items": {"type": "dns-a-record-ipv4"}, "uniqueItems": true, "array": [{"required": ["dns-a-record-ip"], "properties": {"as-replace": {"default": 0, "optional": true, "type": "number", "description": "Return this Service-IP when enable ip-replace", "format": "flag"}, "dns-a-record-ip": {"optional": false, "type": "string", "description": "Specify IP address", "format": "ipv4-address"}, "as-backup": {"default": 0, "optional": true, "type": "number", "description": "As backup when fail", "format": "flag"}, "weight": {"description": "Specify weight for Service-IP (Weight value)", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}, "disable": {"default": 0, "optional": true, "type": "number", "description": "Disable this Service-IP", "format": "flag"}, "static": {"default": 0, "optional": true, "type": "number", "description": "Return this Service-IP in DNS server mode", "format": "flag"}, "ttl": {"optional": true, "type": "number", "description": "Specify TTL for Service-IP", "format": "number"}, "admin-ip": {"description": "Specify admin priority of Service-IP (Specify the priority)", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}, "no-resp": {"default": 0, "optional": true, "type": "number", "description": "Don't use this Service-IP as DNS response", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-a-record/dns-a-record-ipv4/{dns-a-record-ip}"}, "dns-a-record-srv-list": {"minItems": 1, "items": {"type": "dns-a-record-srv"}, "uniqueItems": true, "array": [{"required": ["svrname"], "properties": {"as-replace": {"default": 0, "optional": true, "type": "number", "description": "Return this Service-IP when enable ip-replace", "format": "flag"}, "as-backup": {"default": 0, "optional": true, "type": "number", "description": "As backup when fail", "format": "flag"}, "weight": {"description": "Specify weight for Service-IP (Weight value)", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}, "svrname": {"description": "Specify name", "format": "string", "minLength": 1, "$ref-list": ["/axapi/v3/gslb/service-ip", "/axapi/v3/slb/server"], "optional": false, "maxLength": 63, "type": "string"}, "disable": {"default": 0, "optional": true, "type": "number", "description": "Disable this Service-IP", "format": "flag"}, "static": {"default": 0, "optional": true, "type": "number", "description": "Return this Service-IP in DNS server mode", "format": "flag"}, "ttl": {"optional": true, "type": "number", "description": "Specify TTL for Service-IP", "format": "number"}, "admin-ip": {"description": "Specify admin priority of Service-IP (Specify the priority)", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}, "no-resp": {"default": 0, "optional": true, "type": "number", "description": "Don't use this Service-IP as DNS response", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-a-record/dns-a-record-srv/{svrname}"}}}, "forward-type": {"optional": true, "enum": ["both", "query", "response"], "type": "string", "description": "'both': Forward both query and response; 'query': Forward query; 'response': Forward response; ", "format": "enum"}, "dns-cname-record-list": {"minItems": 1, "items": {"type": "dns-cname-record"}, "uniqueItems": true, "array": [{"required": ["alias-name"], "properties": {"as-backup": {"default": 0, "optional": true, "type": "number", "description": "As backup when fail", "format": "flag"}, "alias-name": {"description": "Specify the alias name", "format": "string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}, "admin-preference": {"description": "Specify Administrative Preference, default is 100", "format": "number", "default": 100, "optional": true, "maximum": 255, "minimum": 0, "type": "number"}, "weight": {"description": "Specify Weight, default is 1", "format": "number", "default": 1, "optional": true, "maximum": 100, "minimum": 1, "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-cname-record/{alias-name}"}, "health-check-port": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "health-check-port": {"description": "Check Related Port Status (Port Number)", "minimum": 0, "type": "number", "maximum": 65534, "format": "number"}}}]}, "policy": {"description": "Specify policy for this service (Specify policy name)", "format": "string", "default": "default", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "dns-txt-record-list": {"minItems": 1, "items": {"type": "dns-txt-record"}, "uniqueItems": true, "array": [{"required": ["record-name"], "properties": {"record-name": {"description": "Specify the Object Name for TXT Data", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "txt-data": {"description": "Specify TXT Data", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 1000, "type": "string"}, "ttl": {"optional": true, "type": "number", "description": "Specify TTL", "format": "number"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-txt-record/{record-name}"}, "service-port": {"description": "Port number of the service", "format": "number", "type": "number", "maximum": 65534, "minimum": 0, "optional": false}, "dns-mx-record-list": {"minItems": 1, "items": {"type": "dns-mx-record"}, "uniqueItems": true, "array": [{"required": ["mx-name"], "properties": {"priority": {"description": "Specify Priority", "format": "number", "type": "number", "maximum": 65535, "minimum": 0, "optional": true}, "mx-name": {"description": "Specify Domain Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}, "ttl": {"optional": true, "type": "number", "description": "Specify TTL", "format": "number"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-mx-record/{mx-name}"}, "dns-record-list": {"minItems": 1, "items": {"type": "dns-record"}, "uniqueItems": true, "array": [{"required": ["type"], "properties": {"data": {"description": "Specify DNS Data", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 512, "type": "string"}, "type": {"description": "Specify DNS Type", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-record/{type}"}, "dns-ns-record-list": {"minItems": 1, "items": {"type": "dns-ns-record"}, "uniqueItems": true, "array": [{"required": ["ns-name"], "properties": {"ns-name": {"description": "Specify Domain Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}, "ttl": {"optional": true, "type": "number", "description": "Specify TTL", "format": "number"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-ns-record/{ns-name}"}, "health-check-gateway": {"description": "'enable': Enable Gateway Status Check; 'disable': Disable Gateway Status Check; ", "format": "enum", "default": "enable", "type": "string", "enum": ["enable", "disable"], "optional": true}, "disable": {"default": 0, "optional": true, "type": "number", "description": "Disable", "format": "flag"}, "dns-srv-record-list": {"minItems": 1, "items": {"type": "dns-srv-record"}, "uniqueItems": true, "array": [{"required": ["srv-name", "port"], "properties": {"priority": {"description": "Specify Priority", "format": "number", "type": "number", "maximum": 65535, "minimum": 0, "optional": true}, "srv-name": {"description": "Specify Domain Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}, "port": {"description": "Specify Port (Port Number)", "format": "number", "type": "number", "maximum": 65534, "minimum": 0, "optional": false}, "weight": {"description": "Specify Weight, default is 10", "format": "number", "default": 10, "optional": true, "maximum": 100, "minimum": 1, "type": "number"}, "ttl": {"optional": true, "type": "number", "description": "Specify TTL", "format": "number"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-srv-record/{srv-name}+{port}"}, "service-name": {"description": "Specify the service name for the zone, * for wildcard", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "action": {"optional": true, "enum": ["drop", "forward", "ignore", "reject"], "type": "string", "description": "'drop': Drop query; 'forward': Forward packet; 'ignore': Send empty response; 'reject': Send refuse response; ", "format": "enum"}, "dns-ptr-record-list": {"minItems": 1, "items": {"type": "dns-ptr-record"}, "uniqueItems": true, "array": [{"required": ["ptr-name"], "properties": {"ptr-name": {"description": "Specify Domain Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}, "ttl": {"optional": true, "type": "number", "description": "Specify TTL", "format": "number"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-ptr-record/{ptr-name}"}, "geo-location-list": {"minItems": 1, "items": {"type": "geo-location"}, "uniqueItems": true, "array": [{"required": ["geo-name"], "properties": {"forward-type": {"optional": true, "enum": ["both", "query", "response"], "type": "string", "description": "'both': Forward both query and response; 'query': Forward query from this geo-location; 'response': Forward response to this geo-location; ", "format": "enum"}, "alias": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"alias": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Send CNAME response for this geo-location (Specify a CNAME record)", "format": "string"}, "optional": true}}]}, "action-type": {"optional": true, "enum": ["allow", "drop", "forward", "ignore", "reject"], "type": "string", "description": "'allow': Allow query from this geo-location; 'drop': Drop query from this geo-location; 'forward': Forward packet for this geo-location; 'ignore': Send empty response to this geo-location; 'reject': Send refuse response to this geo-location; ", "format": "enum"}, "policy": {"description": "Policy for this geo-location (Specify the policy name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "not": "action", "type": "string"}, "action": {"description": "Action for this geo-location", "format": "flag", "default": 0, "optional": true, "not": "policy", "type": "number"}, "geo-name": {"description": "Specify the geo-location", "format": "string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/geo-location/{geo-name}"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}"}
    :param service_ip_list: {"minItems": 1, "items": {"type": "service-ip"}, "uniqueItems": true, "array": [{"required": ["node-name"], "properties": {"health-check-disable": {"description": "Disable Health Check Monitor", "format": "flag", "default": 0, "optional": true, "not": "health-check", "type": "number"}, "port-list": {"minItems": 1, "items": {"type": "port"}, "uniqueItems": true, "array": [{"required": ["port-num", "port-proto"], "properties": {"port-proto": {"optional": false, "enum": ["tcp", "udp"], "type": "string", "description": "'tcp': TCP Port; 'udp': UDP Port; ", "format": "enum"}, "port-num": {"description": "Port Number", "format": "number", "type": "number", "maximum": 65534, "minimum": 0, "optional": false}, "health-check-disable": {"description": "Disable Health Check Monitor", "format": "flag", "default": 0, "optional": true, "not-list": ["health-check", "health-check-follow-port"], "type": "number"}, "follow-port-protocol": {"optional": true, "enum": ["tcp", "udp"], "type": "string", "description": "'tcp': TCP Port; 'udp': UDP Port; ", "format": "enum"}, "action": {"description": "'enable': Enable this GSLB server port; 'disable': Disable this GSLB server port; ", "format": "enum", "default": "enable", "type": "string", "enum": ["enable", "disable"], "optional": true}, "health-check-follow-port": {"description": "Specify which port to follow for health status (Port Number)", "format": "number", "optional": true, "not-list": ["health-check", "health-check-disable"], "maximum": 65534, "minimum": 1, "type": "number"}, "health-check-protocol-disable": {"default": 0, "optional": true, "type": "number", "description": "Disable GSLB Protocol Health Monitor", "format": "flag"}, "health-check": {"description": "Health Check Monitor (Monitor Name)", "format": "string", "minLength": 1, "not-list": ["health-check-follow-port", "health-check-disable"], "optional": true, "maxLength": 31, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/gslb/service-ip/{node-name}/port/{port-num}+{port-proto}"}, "external-ip": {"optional": true, "type": "string", "description": "External IP address for NAT", "format": "ipv4-address"}, "health-check": {"description": "Health Check Monitor (Monitor Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "not": "health-check-disable", "type": "string"}, "node-name": {"description": "Service-IP Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "ip-address": {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "IP address", "format": "ipv4-address"}, "ipv6": {"optional": true, "type": "string", "description": "IPv6 address Mapping", "format": "ipv6-address"}, "ipv6-address": {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "IPV6 address", "format": "ipv6-address"}, "health-check-protocol-disable": {"default": 0, "optional": true, "type": "number", "description": "Disable GSLB Protocol Health Monitor", "format": "flag"}, "action": {"description": "'enable': Enable this GSLB server; 'disable': Disable this GSLB server; ", "format": "enum", "default": "enable", "type": "string", "enum": ["enable", "disable"], "optional": true}}}], "type": "array", "$ref": "/axapi/v3/gslb/service-ip/{node-name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "gslb"
        self.a10_url="/axapi/v3/gslb"
        self.DeviceProxy = ""
        self.protocol = {}
        self.template = {}
        self.service_group_list = []
        self.system = {}
        self.geo_location_list = []
        self.policy_list = []
        self.site_list = []
        self.ip_list_list = []
        self.dns = {}
        self.group_list = []
        self.zone_list = []
        self.active_rdt = {}
        self.service_ip_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param icmpv6_rcv: {"description": "ICMPv6 Received", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param tcp_rcv: {"description": "TCP Received", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param other_rcv: {"description": "Other Received", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param udp_dropped: {"description": "UDP Dropped", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param bad_ip_len: {"description": "Bad IP Length", "format": "counter", "type": "number", "oid": "18", "optional": true, "size": "8"}
    :param first_l4_too_small: {"description": "First L4 Fragment Too Small Drop", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "8"}
    :param no_session_memory: {"description": "Out of Session Memory", "format": "counter", "type": "number", "oid": "23", "optional": true, "size": "8"}
    :param unaligned_len: {"description": "Payload Length Unaligned", "format": "counter", "type": "number", "oid": "27", "optional": true, "size": "8"}
    :param icmp_dropped: {"description": "ICMP Dropped", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param udp_rcv: {"description": "UDP Received", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param exceeded_len: {"description": "Payload Length Out of Bounds", "format": "counter", "type": "number", "oid": "28", "optional": true, "size": "8"}
    :param fragment_queue_success: {"description": "Fragment Queue Success", "format": "counter", "type": "number", "oid": "26", "optional": true, "size": "8"}
    :param fragment_queue_failure: {"description": "Fragment Queue Failure", "format": "counter", "type": "number", "oid": "32", "optional": true, "size": "8"}
    :param total_fragments_exceeded: {"description": "Total Queued Fragments Exceeded", "format": "counter", "type": "number", "oid": "31", "optional": true, "size": "8"}
    :param tcp_dropped: {"description": "TCP Dropped", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "8"}
    :param ipip_dropped: {"description": "IP-in-IP Dropped", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "8"}
    :param total_sessions_exceeded: {"description": "Total Sessions Exceeded Drop", "format": "counter", "type": "number", "oid": "22", "optional": true, "size": "8"}
    :param error_drop: {"description": "Fragment Processing Drop", "format": "counter", "type": "number", "oid": "37", "optional": true, "size": "8"}
    :param overlap_error: {"description": "Overlapping Fragment Dropped", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "8"}
    :param ipv6ip_rcv: {"description": "IPv6-in-IP Received", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param session_expired: {"description": "Session Expired", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param policy_drop: {"description": "MTU Exceeded Policy Drop", "format": "counter", "type": "number", "oid": "36", "optional": true, "size": "8"}
    :param icmp_rcv: {"description": "ICMP Received", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param session_packets_exceeded: {"description": "Session Max Packets Exceeded", "format": "counter", "type": "number", "oid": "39", "optional": true, "size": "8"}
    :param duplicate_first_frag: {"description": "Duplicate First Fragment", "format": "counter", "type": "number", "oid": "29", "optional": true, "size": "8"}
    :param reassembly_success: {"description": "Fragment Reassembly Success", "format": "counter", "type": "number", "oid": "33", "optional": true, "size": "8"}
    :param too_small: {"description": "Fragment Too Small Drop", "format": "counter", "type": "number", "oid": "19", "optional": true, "size": "8"}
    :param ipv6ip_dropped: {"description": "IPv6-in-IP Dropped", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "8"}
    :param session_inserted: {"description": "Session Inserted", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param max_len_exceeded: {"description": "Fragment Max Data Length Exceeded", "format": "counter", "type": "number", "oid": "34", "optional": true, "size": "8"}
    :param max_packets_exceeded: {"description": "Too Many Packets Per Reassembly Drop", "format": "counter", "type": "number", "oid": "38", "optional": true, "size": "8"}
    :param other_dropped: {"description": "Other Dropped", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "8"}
    :param first_tcp_too_small: {"description": "First TCP Fragment Too Small Drop", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "8"}
    :param fast_aging_set: {"description": "Fragmentation Fast Aging Set", "format": "counter", "type": "number", "oid": "24", "optional": true, "size": "8"}
    :param ipip_rcv: {"description": "IP-in-IP Received", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param icmpv6_dropped: {"description": "ICMPv6 Dropped", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param fast_aging_unset: {"description": "Fragmentation Fast Aging Unset", "format": "counter", "type": "number", "oid": "25", "optional": true, "size": "8"}
    :param reassembly_failure: {"description": "Fragment Reassembly Failure", "format": "counter", "type": "number", "oid": "35", "optional": true, "size": "8"}
    :param duplicate_last_frag: {"description": "Duplicate Last Fragment", "format": "counter", "type": "number", "oid": "30", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.icmpv6_rcv = ""
        self.tcp_rcv = ""
        self.other_rcv = ""
        self.udp_dropped = ""
        self.bad_ip_len = ""
        self.first_l4_too_small = ""
        self.no_session_memory = ""
        self.unaligned_len = ""
        self.icmp_dropped = ""
        self.udp_rcv = ""
        self.exceeded_len = ""
        self.fragment_queue_success = ""
        self.fragment_queue_failure = ""
        self.total_fragments_exceeded = ""
        self.tcp_dropped = ""
        self.ipip_dropped = ""
        self.total_sessions_exceeded = ""
        self.error_drop = ""
        self.overlap_error = ""
        self.ipv6ip_rcv = ""
        self.session_expired = ""
        self.policy_drop = ""
        self.icmp_rcv = ""
        self.session_packets_exceeded = ""
        self.duplicate_first_frag = ""
        self.reassembly_success = ""
        self.too_small = ""
        self.ipv6ip_dropped = ""
        self.session_inserted = ""
        self.max_len_exceeded = ""
        self.max_packets_exceeded = ""
        self.other_dropped = ""
        self.first_tcp_too_small = ""
        self.fast_aging_set = ""
        self.ipip_rcv = ""
        self.icmpv6_dropped = ""
        self.fast_aging_unset = ""
        self.reassembly_failure = ""
        self.duplicate_last_frag = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Frag(A10BaseClass):
    
    """Class Description::
    Statistics for the object frag.

    Class frag supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ipv4-in-ipv6/frag/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "frag"
        self.a10_url="/axapi/v3/ipv4-in-ipv6/frag/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param radius_request_dropped: {"description": "RADIUS Request Dropped (Malformed Packet)", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param imsi_received: {"description": "IMSI Received", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param ha_standby_dropped: {"description": "HA Standby Dropped", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param custom_received: {"description": "Custom attribute Received", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param imei_received: {"description": "IMEI Received", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param radius_table_full: {"description": "RADIUS Request Dropped (Table Full)", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param msisdn_received: {"description": "MSISDN Received", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param radius_request_received: {"description": "RADIUS Request Received", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.radius_request_dropped = ""
        self.imsi_received = ""
        self.ha_standby_dropped = ""
        self.custom_received = ""
        self.imei_received = ""
        self.radius_table_full = ""
        self.msisdn_received = ""
        self.radius_request_received = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Server(A10BaseClass):
    
    """Class Description::
    Statistics for the object server.

    Class server supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/lsn/radius/server/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "server"
        self.a10_url="/axapi/v3/cgnv6/lsn/radius/server/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class CalcSha1(A10BaseClass):
    
    """    :param sha1_value: {"description": "Cleartext password", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    Calculate sha1 value of a cleartext password.

    Class calc-sha1 supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/dblb/{name}/calc-sha1`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "calc-sha1"
        self.a10_url="/axapi/v3/slb/template/dblb/{name}/calc-sha1"
        self.DeviceProxy = ""
        self.sha1_value = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Udp(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param udp_sessions: {"description": "Number of Extended Quota sessions allowed for this service", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param udp_service_port: {"description": "Port (Port Value)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "udp"
        self.DeviceProxy = ""
        self.udp_sessions = ""
        self.udp_service_port = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Tcp(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param tcp_service_port: {"description": "Port (Port Value)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param tcp_sessions: {"description": "Number of Extended Quota sessions allowed for this service", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "tcp"
        self.DeviceProxy = ""
        self.tcp_service_port = ""
        self.tcp_sessions = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ExtendedUserQuota(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param udp: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"udp-sessions": {"description": "Number of Extended Quota sessions allowed for this service", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "optional": true, "udp-service-port": {"description": "Port (Port Value)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}}}]}
    :param tcp: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"tcp-service-port": {"description": "Port (Port Value)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "optional": true, "tcp-sessions": {"description": "Number of Extended Quota sessions allowed for this service", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "extended-user-quota"
        self.DeviceProxy = ""
        self.udp = []
        self.tcp = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class DsLite(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param inside_src_permit_list: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Class-List of IPv4 addresses permitted (Class-list to match for DS-Lite)", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ds-lite"
        self.DeviceProxy = ""
        self.inside_src_permit_list = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class QuotaTcp(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param tcp_quota: {"description": "NAT port quota per user (default: not configured)", "minimum": 1, "type": "number", "maximum": 64000, "format": "number"}
    :param tcp_reserve: {"description": "Number of ports to reserve per user (default: same as user-quota value) (Reserved quota per user (default: same as user-quota value))", "minimum": 0, "type": "number", "maximum": 64000, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "quota-tcp"
        self.DeviceProxy = ""
        self.tcp_quota = ""
        self.tcp_reserve = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class QuotaUdp(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param udp_reserve: {"description": "Number of ports to reserve per user (default: same as user-quota value) (Reserved quota per user (default: same as user-quota value))", "minimum": 0, "type": "number", "maximum": 64000, "format": "number"}
    :param udp_quota: {"description": "NAT port quota per user (default: not configured)", "minimum": 1, "type": "number", "maximum": 64000, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "quota-udp"
        self.DeviceProxy = ""
        self.udp_reserve = ""
        self.udp_quota = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class UserQuota(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param session: {"description": "User Quota for number of data sessions", "minimum": 1, "type": "number", "maximum": 2147483647, "format": "number"}
    :param icmp: {"description": "User Quota for ICMP identifiers (NAT port quota per user (default: not configured))", "minimum": 1, "type": "number", "maximum": 64000, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "user-quota"
        self.DeviceProxy = ""
        self.session = ""
        self.quota_tcp = {}
        self.icmp = ""
        self.quota_udp = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class SourceNatPool(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param shared: {"default": 0, "type": "number", "description": "Use a shared source NAT pool or pool-group", "format": "flag"}
    :param pool_name: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Source NAT Pool or Pool-Group", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "source-nat-pool"
        self.DeviceProxy = ""
        self.shared = ""
        self.pool_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ConnRateLimit(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param conn_rate_limit_val: {"description": "Maximum connections per second (Default: No limit)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "conn-rate-limit"
        self.DeviceProxy = ""
        self.conn_rate_limit_val = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class LsnRuleList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param destination: {"description": "Apply LSN Rule-List on Destination (LSN Rule-List Name)", "format": "string-rlx", "minLength": 1, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/cgnv6/lsn-rule-list"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "lsn-rule-list"
        self.DeviceProxy = ""
        self.destination = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class LsnLid(A10BaseClass):
    
    """Class Description::
    Create an LSN Lid.

    Class lsn-lid supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param drop_on_nat_pool_mismatch: {"default": 0, "optional": true, "type": "number", "description": "Drop traffic from users if their current NAT pool does not match the lid's (default: off)", "format": "flag"}
    :param user_quota_prefix_length: {"description": "NAT64 user quota prefix length (Prefix Length (Default: Uses the global NAT64 configured value))", "format": "number", "type": "number", "maximum": 128, "minimum": 1, "optional": true}
    :param lid_number: {"description": "LSN Lid", "format": "number", "type": "number", "maximum": 1023, "minimum": 1, "optional": false}
    :param override: {"description": "'none': Apply source NAT if configured (default); 'drop': Drop packets that match this LSN lid; 'pass-through': Layer-3 route packets that match this LSN lid and do not apply source NAT; ", "format": "enum", "default": "none", "type": "string", "enum": ["none", "drop", "pass-through"], "optional": true}
    :param respond_to_user_mac: {"default": 0, "optional": true, "type": "number", "description": "Use the user's source MAC for the next hop rather than the routing table (default: off)", "format": "flag"}
    :param name: {"description": "LSN Lid Name", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/lsn-lid/{lid_number}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "lid_number"]

        self.b_key = "lsn-lid"
        self.a10_url="/axapi/v3/cgnv6/lsn-lid/{lid_number}"
        self.DeviceProxy = ""
        self.drop_on_nat_pool_mismatch = ""
        self.user_quota_prefix_length = ""
        self.lid_number = ""
        self.extended_user_quota = {}
        self.ds_lite = {}
        self.user_quota = {}
        self.override = ""
        self.source_nat_pool = {}
        self.conn_rate_limit = {}
        self.lsn_rule_list = {}
        self.respond_to_user_mac = ""
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class VeCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ve_end: {"type": "number", "description": "VE port", "format": "number"}
    :param ve_start: {"type": "number", "description": "VE port (VE Interface number)", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ve-cfg"
        self.DeviceProxy = ""
        self.ve_end = ""
        self.ve_start = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class EthCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ethernet_start: {"type": "number", "description": "Ethernet port (Ethernet Interface number)", "format": "interface"}
    :param ethernet_end: {"type": "number", "description": "Ethernet port", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "eth-cfg"
        self.DeviceProxy = ""
        self.ethernet_start = ""
        self.ethernet_end = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AclV6(A10BaseClass):
    
    """Class Description::
    IPv6 ACL for Ping service.

    Class acl-v6 supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param acl_name: {"description": "ACL name", "format": "string", "minLength": 1, "optional": false, "maxLength": 16, "type": "string"}
    :param ve_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ve-end": {"type": "number", "description": "VE port", "format": "number"}, "ve-start": {"type": "number", "description": "VE port (VE Interface number)", "format": "number"}, "optional": true}}]}
    :param eth_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ethernet-start": {"type": "number", "description": "Ethernet port (Ethernet Interface number)", "format": "interface"}, "ethernet-end": {"type": "number", "description": "Ethernet port", "format": "interface"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/enable-management/service/ping/acl-v6/{acl_name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "acl_name"]

        self.b_key = "acl-v6"
        self.a10_url="/axapi/v3/enable-management/service/ping/acl-v6/{acl_name}"
        self.DeviceProxy = ""
        self.acl_name = ""
        self.ve_cfg = []
        self.eth_cfg = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class SourceIp(A10BaseClass):
    
    """Class Description::
    Source IP persistence.

    Class source-ip supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param scan_all_members: {"default": 0, "optional": true, "type": "number", "description": "Persist with SCAN of all members", "format": "flag"}
    :param netmask6: {"description": "IPV6 subnet mask", "format": "number", "default": 128, "optional": true, "maximum": 128, "minimum": 1, "type": "number"}
    :param incl_dst_ip: {"default": 0, "optional": true, "type": "number", "description": "Include destination IP on the persist", "format": "flag"}
    :param name: {"description": "Source IP persistence template name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param dont_honor_conn_rules: {"default": 0, "optional": true, "type": "number", "description": "Do not observe connection rate rules", "format": "flag"}
    :param service_group: {"description": "Persist within the same service group", "format": "flag", "default": 0, "optional": true, "not": "server", "type": "number"}
    :param server: {"description": "Persist to the same server, default is port", "format": "flag", "default": 0, "optional": true, "not": "service-group", "type": "number"}
    :param incl_sport: {"default": 0, "optional": true, "type": "number", "description": "Include source port on the persist", "format": "flag"}
    :param netmask: {"default": "255.255.255.255", "optional": true, "type": "string", "description": "IP subnet mask", "format": "ipv4-netmask"}
    :param timeout: {"description": "Persistence timeout (in minutes)", "format": "number", "default": 5, "optional": true, "maximum": 2000, "minimum": 1, "type": "number"}
    :param hash_persist: {"default": 0, "optional": true, "type": "number", "description": "Use hash value of source IP address", "format": "flag"}
    :param enforce_higher_priority: {"default": 0, "optional": true, "type": "number", "description": "Enforce to use high priority node if available", "format": "flag"}
    :param match_type: {"default": 0, "optional": true, "type": "number", "description": "Persistence type", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/persist/source-ip/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "source-ip"
        self.a10_url="/axapi/v3/slb/template/persist/source-ip/{name}"
        self.DeviceProxy = ""
        self.scan_all_members = ""
        self.netmask6 = ""
        self.incl_dst_ip = ""
        self.name = ""
        self.dont_honor_conn_rules = ""
        self.service_group = ""
        self.server = ""
        self.incl_sport = ""
        self.netmask = ""
        self.timeout = ""
        self.hash_persist = ""
        self.enforce_higher_priority = ""
        self.match_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class KeyRollover(A10BaseClass):
    
    """    :param ds_ready_in_parent_zone: {"default": 0, "optional": true, "type": "number", "description": "DS RR is already ready in the parent zone", "format": "flag"}
    :param zsk_start: {"default": 0, "optional": true, "type": "number", "description": "start ZSK rollover in emergency mode", "format": "flag"}
    :param ksk_start: {"default": 0, "optional": true, "type": "number", "description": "start KSK rollover in emergency mode", "format": "flag"}
    :param dnssec_key_type: {"optional": true, "enum": ["ZSK", "KSK"], "type": "string", "description": "'ZSK': Zone Signing Key; 'KSK': Key Signing Key; ", "format": "enum"}
    :param zone_name: {"description": "Specify the name for the DNS zone", "format": "string", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    DNSSEC Key rollover.

    Class key-rollover supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/dnssec/key-rollover`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "key-rollover"
        self.a10_url="/axapi/v3/dnssec/key-rollover"
        self.DeviceProxy = ""
        self.ds_ready_in_parent_zone = ""
        self.zsk_start = ""
        self.ksk_start = ""
        self.dnssec_key_type = ""
        self.zone_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class VipMap(A10BaseClass):
    
    """Class Description::
    VIP redistribution map.

    Class vip-map supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param floating_IP_forward_address: {"optional": true, "type": "string", "description": "Floating-IP as forward address. help-val Address", "format": "ipv4-address"}
    :param vip_address: {"optional": false, "type": "string", "description": "Address", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/ospf/{process_id}/redistribute/vip/vip-map/{vip_address}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "vip_address"]

        self.b_key = "vip-map"
        self.a10_url="/axapi/v3/router/ospf/{process_id}/redistribute/vip/vip-map/{vip_address}"
        self.DeviceProxy = ""
        self.floating_IP_forward_address = ""
        self.vip_address = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class ServerRequestHeader(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param server_request_header_insert: {"minLength": 1, "maxLength": 127, "type": "string", "description": "Insert a SIP header (Header Content (Format: \"name: value\"))", "format": "string-rlx"}
    :param server_request_erase_all: {"default": 0, "type": "number", "description": "Erase all headers", "format": "flag"}
    :param insert_condition_server_request: {"enum": ["insert-if-not-exist", "insert-always"], "type": "string", "description": "'insert-if-not-exist': Only insert the header when it does not exist; 'insert-always': Always insert the header even when there is a header with the same name; ", "format": "enum"}
    :param server_request_header_erase: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Erase a SIP header (Header Name)", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "server-request-header"
        self.DeviceProxy = ""
        self.server_request_header_insert = ""
        self.server_request_erase_all = ""
        self.insert_condition_server_request = ""
        self.server_request_header_erase = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ServerResponseHeader(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param server_response_header_insert: {"minLength": 1, "maxLength": 127, "type": "string", "description": "Insert a SIP header (Header Content (Format: \"name: value\"))", "format": "string-rlx"}
    :param server_response_header_erase: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Erase a SIP header (Header Name)", "format": "string-rlx"}
    :param server_response_erase_all: {"default": 0, "type": "number", "description": "Erase all headers", "format": "flag"}
    :param insert_condition_server_response: {"enum": ["insert-if-not-exist", "insert-always"], "type": "string", "description": "'insert-if-not-exist': Only insert the header when it does not exist; 'insert-always': Always insert the header even when there is a header with the same name; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "server-response-header"
        self.DeviceProxy = ""
        self.server_response_header_insert = ""
        self.server_response_header_erase = ""
        self.server_response_erase_all = ""
        self.insert_condition_server_response = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ClientRequestHeader(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param client_request_header_erase: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Erase a SIP header (Header Name)", "format": "string-rlx"}
    :param client_request_header_insert: {"minLength": 1, "maxLength": 127, "type": "string", "description": "Insert a SIP header (Header Content (Format: \"name: value\"))", "format": "string-rlx"}
    :param client_request_erase_all: {"default": 0, "type": "number", "description": "Erase all headers", "format": "flag"}
    :param insert_condition_client_request: {"enum": ["insert-if-not-exist", "insert-always"], "type": "string", "description": "'insert-if-not-exist': Only insert the header when it does not exist; 'insert-always': Always insert the header even when there is a header with the same name; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "client-request-header"
        self.DeviceProxy = ""
        self.client_request_header_erase = ""
        self.client_request_header_insert = ""
        self.client_request_erase_all = ""
        self.insert_condition_client_request = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ClientResponseHeader(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param client_response_erase_all: {"default": 0, "type": "number", "description": "Erase all headers", "format": "flag"}
    :param insert_condition_client_response: {"enum": ["insert-if-not-exist", "insert-always"], "type": "string", "description": "'insert-if-not-exist': Only insert the header when it does not exist; 'insert-always': Always insert the header even when there is a header with the same name; ", "format": "enum"}
    :param client_response_header_insert: {"minLength": 1, "maxLength": 127, "type": "string", "description": "Insert a SIP header (Header Content (Format: \"name: value\"))", "format": "string-rlx"}
    :param client_response_header_erase: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Erase a SIP header (Header Name)", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "client-response-header"
        self.DeviceProxy = ""
        self.client_response_erase_all = ""
        self.insert_condition_client_response = ""
        self.client_response_header_insert = ""
        self.client_response_header_erase = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ExcludeTranslation(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param translation_value: {"enum": ["start-line", "header", "body"], "type": "string", "description": "'start-line': SIP request line or status line; 'header': SIP message headers; 'body': SIP message body; ", "format": "enum"}
    :param header_string: {"minLength": 1, "maxLength": 63, "type": "string", "description": "SIP header name", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "exclude-translation"
        self.DeviceProxy = ""
        self.translation_value = ""
        self.header_string = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Sip(A10BaseClass):
    
    """Class Description::
    SIP Template.

    Class sip supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param server_request_header: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"server-request-header-insert": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Insert a SIP header (Header Content (Format: \"name: value\"))", "format": "string-rlx"}, "server-request-erase-all": {"default": 0, "type": "number", "description": "Erase all headers", "format": "flag"}, "optional": true, "insert-condition-server-request": {"enum": ["insert-if-not-exist", "insert-always"], "type": "string", "description": "'insert-if-not-exist': Only insert the header when it does not exist; 'insert-always': Always insert the header even when there is a header with the same name; ", "format": "enum"}, "server-request-header-erase": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Erase a SIP header (Header Name)", "format": "string-rlx"}}}]}
    :param keep_server_ip_if_match_acl: {"default": 0, "optional": true, "type": "number", "description": "Use Real Server IP for addresses matching the ACL for a Call-Id", "format": "flag"}
    :param client_keep_alive: {"default": 0, "optional": true, "type": "number", "description": "Respond client keep-alive packet directly instead of forwarding to server", "format": "flag"}
    :param alg_source_nat: {"default": 0, "optional": true, "type": "number", "description": "Translate source IP to NAT IP in SIP message when source NAT is used", "format": "flag"}
    :param server_response_header: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"server-response-header-insert": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Insert a SIP header (Header Content (Format: \"name: value\"))", "format": "string-rlx"}, "server-response-header-erase": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Erase a SIP header (Header Name)", "format": "string-rlx"}, "optional": true, "server-response-erase-all": {"default": 0, "type": "number", "description": "Erase all headers", "format": "flag"}, "insert-condition-server-response": {"enum": ["insert-if-not-exist", "insert-always"], "type": "string", "description": "'insert-if-not-exist': Only insert the header when it does not exist; 'insert-always': Always insert the header even when there is a header with the same name; ", "format": "enum"}}}]}
    :param server_selection_per_request: {"default": 0, "optional": true, "type": "number", "description": "Force server selection on every SIP request", "format": "flag"}
    :param client_request_header: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"client-request-header-erase": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Erase a SIP header (Header Name)", "format": "string-rlx"}, "optional": true, "client-request-header-insert": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Insert a SIP header (Header Content (Format: \"name: value\"))", "format": "string-rlx"}, "client-request-erase-all": {"default": 0, "type": "number", "description": "Erase all headers", "format": "flag"}, "insert-condition-client-request": {"enum": ["insert-if-not-exist", "insert-always"], "type": "string", "description": "'insert-if-not-exist': Only insert the header when it does not exist; 'insert-always': Always insert the header even when there is a header with the same name; ", "format": "enum"}}}]}
    :param service_group: {"description": "service group name", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}
    :param insert_client_ip: {"default": 0, "optional": true, "type": "number", "description": "Insert Client IP address into SIP header", "format": "flag"}
    :param failed_client_selection: {"default": 0, "optional": true, "type": "number", "description": "Define action when select client fail", "format": "flag"}
    :param failed_client_selection_message: {"description": "Send SIP message (includs status code) to server when select client fail(Format: 3 digits(1XX~6XX) space reason)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "not": "drop-when-client-fail", "type": "string"}
    :param call_id_persist_disable: {"default": 0, "optional": true, "type": "number", "description": "Disable call-ID persistence", "format": "flag"}
    :param acl_id: {"description": "ACL id", "format": "number", "optional": true, "maximum": 199, "minimum": 100, "not": "acl-name-value", "type": "number", "$ref": "/axapi/v3/access-list/standard"}
    :param alg_dest_nat: {"default": 0, "optional": true, "type": "number", "description": "Translate VIP to real server IP in SIP message when destination NAT is used", "format": "flag"}
    :param server_keep_alive: {"default": 0, "optional": true, "type": "number", "description": "Send server keep-alive packet for every persist connection when enable conn-reuse", "format": "flag"}
    :param client_response_header: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"client-response-erase-all": {"default": 0, "type": "number", "description": "Erase all headers", "format": "flag"}, "insert-condition-client-response": {"enum": ["insert-if-not-exist", "insert-always"], "type": "string", "description": "'insert-if-not-exist': Only insert the header when it does not exist; 'insert-always': Always insert the header even when there is a header with the same name; ", "format": "enum"}, "optional": true, "client-response-header-insert": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Insert a SIP header (Header Content (Format: \"name: value\"))", "format": "string-rlx"}, "client-response-header-erase": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Erase a SIP header (Header Name)", "format": "string-rlx"}}}]}
    :param failed_server_selection_message: {"description": "Send SIP message (includs status code) to client when select server fail(Format: 3 digits(1XX~6XX) space reason)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "not": "drop-when-server-fail", "type": "string"}
    :param name: {"description": "SIP Template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param exclude_translation: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"translation-value": {"enum": ["start-line", "header", "body"], "type": "string", "description": "'start-line': SIP request line or status line; 'header': SIP message headers; 'body': SIP message body; ", "format": "enum"}, "optional": true, "header-string": {"minLength": 1, "maxLength": 63, "type": "string", "description": "SIP header name", "format": "string-rlx"}}}]}
    :param interval: {"description": "The interval of keep-alive packet for each persist connection (second)", "format": "number", "default": 30, "optional": true, "maximum": 300, "minimum": 5, "type": "number"}
    :param dialog_aware: {"default": 0, "optional": true, "type": "number", "description": "Permit system processes dialog session", "format": "flag"}
    :param failed_server_selection: {"default": 0, "optional": true, "type": "number", "description": "Define action when select server fail", "format": "flag"}
    :param drop_when_client_fail: {"description": "Drop current SIP message when select client fail", "format": "flag", "default": 0, "optional": true, "not": "failed-client-selection-message", "type": "number"}
    :param timeout: {"description": "Time in minutes", "format": "number", "default": 30, "optional": true, "maximum": 250, "minimum": 1, "type": "number"}
    :param drop_when_server_fail: {"description": "Drop current SIP message when select server fail", "format": "flag", "default": 0, "optional": true, "not": "failed-server-selection-message", "type": "number"}
    :param acl_name_value: {"description": "IPv4 Access List Name", "format": "string", "minLength": 1, "optional": true, "maxLength": 16, "not": "acl-id", "type": "string", "$ref": "/axapi/v3/ip/access-list"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/sip/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "sip"
        self.a10_url="/axapi/v3/slb/template/sip/{name}"
        self.DeviceProxy = ""
        self.server_request_header = []
        self.keep_server_ip_if_match_acl = ""
        self.client_keep_alive = ""
        self.alg_source_nat = ""
        self.server_response_header = []
        self.server_selection_per_request = ""
        self.client_request_header = []
        self.service_group = ""
        self.insert_client_ip = ""
        self.failed_client_selection = ""
        self.failed_client_selection_message = ""
        self.call_id_persist_disable = ""
        self.acl_id = ""
        self.alg_dest_nat = ""
        self.server_keep_alive = ""
        self.client_response_header = []
        self.failed_server_selection_message = ""
        self.name = ""
        self.exclude_translation = []
        self.interval = ""
        self.dialog_aware = ""
        self.failed_server_selection = ""
        self.drop_when_client_fail = ""
        self.timeout = ""
        self.drop_when_server_fail = ""
        self.acl_name_value = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class PreemptMode(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param threshold: {"description": "preemption threshold (preemption threshhold (1-255), default 1)", "format": "number", "default": 1, "maximum": 255, "minimum": 1, "type": "number"}
    :param disable: {"default": 0, "type": "number", "description": "disable preemption", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "preempt-mode"
        self.DeviceProxy = ""
        self.threshold = ""
        self.disable = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipv6AddressPartCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ethernet: {"type": "number", "description": "Ethernet (for link-local address only)", "format": "interface"}
    :param ipv6_address_partition: {"partition-visibility": "private", "platform-specific-default": 1, "type": "string", "description": "IPV6 address", "format": "ipv6-address"}
    :param ve: {"description": "VE interface (for link-local address only)", "minimum": 2, "type": "number", "maximum": 4094, "format": "number"}
    :param trunk: {"description": "Trunk interface (for link-local address only)", "minimum": 1, "type": "number", "maximum": 4096, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ipv6-address-part-cfg"
        self.DeviceProxy = ""
        self.ethernet = ""
        self.ipv6_address_partition = ""
        self.ve = ""
        self.trunk = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class IpAddressCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ip_address: {"partition-visibility": "shared", "platform-specific-default": 1, "type": "string", "description": "IP Address", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ip-address-cfg"
        self.DeviceProxy = ""
        self.ip_address = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class IpAddressPartCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ip_address_partition: {"partition-visibility": "private", "platform-specific-default": 1, "type": "string", "description": "IP Address", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ip-address-part-cfg"
        self.DeviceProxy = ""
        self.ip_address_partition = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipv6AddressCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ipv6_address: {"partition-visibility": "shared", "platform-specific-default": 1, "type": "string", "description": "IPV6 address", "format": "ipv6-address"}
    :param ethernet: {"type": "number", "description": "Ethernet (for link-local address only)", "format": "interface"}
    :param ve: {"description": "VE interface (for link-local address only)", "minimum": 2, "type": "number", "maximum": 4094, "format": "number"}
    :param trunk: {"description": "Trunk interface (for link-local address only)", "minimum": 1, "type": "number", "maximum": 4096, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ipv6-address-cfg"
        self.DeviceProxy = ""
        self.ipv6_address = ""
        self.ethernet = ""
        self.ve = ""
        self.trunk = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class FloatingIp(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ipv6_address_part_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ethernet": {"type": "number", "description": "Ethernet (for link-local address only)", "format": "interface"}, "ipv6-address-partition": {"partition-visibility": "private", "platform-specific-default": 1, "type": "string", "description": "IPV6 address", "format": "ipv6-address"}, "optional": true, "ve": {"description": "VE interface (for link-local address only)", "minimum": 2, "type": "number", "maximum": 4094, "format": "number"}, "trunk": {"description": "Trunk interface (for link-local address only)", "minimum": 1, "type": "number", "maximum": 4096, "format": "number"}}}]}
    :param ip_address_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "ip-address": {"partition-visibility": "shared", "platform-specific-default": 1, "type": "string", "description": "IP Address", "format": "ipv4-address"}}}]}
    :param ip_address_part_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ip-address-partition": {"partition-visibility": "private", "platform-specific-default": 1, "type": "string", "description": "IP Address", "format": "ipv4-address"}, "optional": true}}]}
    :param ipv6_address_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ipv6-address": {"partition-visibility": "shared", "platform-specific-default": 1, "type": "string", "description": "IPV6 address", "format": "ipv6-address"}, "ethernet": {"type": "number", "description": "Ethernet (for link-local address only)", "format": "interface"}, "optional": true, "ve": {"description": "VE interface (for link-local address only)", "minimum": 2, "type": "number", "maximum": 4094, "format": "number"}, "trunk": {"description": "Trunk interface (for link-local address only)", "minimum": 1, "type": "number", "maximum": 4096, "format": "number"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "floating-ip"
        self.DeviceProxy = ""
        self.ipv6_address_part_cfg = []
        self.ip_address_cfg = []
        self.ip_address_part_cfg = []
        self.ipv6_address_cfg = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Follow(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param vrid_lead: {"description": "Define a VRRP-A VRID leader", "partition-visibility": "private", "minLength": 1, "format": "string", "maxLength": 128, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "follow"
        self.DeviceProxy = ""
        self.vrid_lead = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Vrid(A10BaseClass):
    
    """Class Description::
    Specify VRRP-A vrid.

    Class vrid supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param vrid_val: {"description": "Specify ha VRRP-A vrid", "format": "number", "default": 0, "optional": false, "maximum": 31, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vrrp-a/vrid/{vrid_val}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "vrid_val"]

        self.b_key = "vrid"
        self.a10_url="/axapi/v3/vrrp-a/vrid/{vrid_val}"
        self.DeviceProxy = ""
        self.preempt_mode = {}
        self.blade_parameters = {}
        self.floating_ip = {}
        self.vrid_val = ""
        self.follow = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


